@@ -2,7 +2,7 @@ import os
 
 import pytest
 
-from tktl.core.clients import TaktileClient
+from tktl.core.clients import DeploymentApiClient
 from tktl.core.config import settings
 from tktl.core.exceptions import TaktileSdkError
 from tktl.core.managers.auth import AuthConfigManager
@@ -11,9 +11,9 @@ from tktl.core.managers.auth import AuthConfigManager
 def test_instantiate_taktile_client():
     key = os.environ["TEST_USER_API_KEY"]
     AuthConfigManager.set_api_key(key)
-    client = TaktileClient(api_url=settings.DEPLOYMENT_API_URL)
+    client = DeploymentApiClient()
     with pytest.raises(TaktileSdkError):
-        r = client.get_endpoints_for_repository("admin/df.asfm")
+        client.get_endpoint_by_name("admin/df.asfm", "", "")
     assert "X-Api-Key" in client.default_headers
     assert client.default_headers["X-Api-Key"] == key
     assert (
