@@ -1,8 +1,8 @@
 import click
-import colorama
-from click._compat import get_text_stderr
+import colorama  # type: ignore
+from click._compat import get_text_stderr  # type: ignore
 
-import tktl.cli.login
+import tktl.cli.login  # noqa: F401
 
 
 def show(self, file=None):
@@ -27,4 +27,4 @@ def show(self, file=None):
 
 
 # not-very-elegant way to color click's error messages
-click.exceptions.UsageError.show = show
+click.exceptions.UsageError.show = show  # type: ignore
