@@ -1,10 +1,11 @@
 import click
 from pydantic import UUID4
 
-from tktl.cli.common import ClickGroup, logger, to_uuid
+from tktl.cli.common import ClickGroup, to_uuid
 from tktl.commands.deployments import DeleteDeployment
 from tktl.core.config import settings
 from tktl.core.exceptions.exceptions import APIClientException
+from tktl.core.loggers import LOG
 from tktl.login import validate_decorator
 
 
@@ -26,12 +27,12 @@ def delete_deployment_by_id(deployment_id: UUID4):
         show_default=False,
     )
     if inp != "y":
-        logger.error("Safe choice!")
+        LOG.error("Safe choice!")
     command = DeleteDeployment()
     try:
         response = command.execute(deployment_id=deployment_id)
     except APIClientException:
-        logger.error("Only super users have access to this method at this time")
+        LOG.error("Only super users have access to this method at this time")
         return
-    logger.warning(f"Deployment with id: {response.id}")
+    LOG.warning(f"Deployment with id: {response.id}")
     return response
