@@ -10,14 +10,18 @@ from tktl.core.schemas.repository import Endpoint
 class GetDeployments(BaseDeploymentApiCommand):
     def execute(
         self,
-        deployment_id: UUID4,
+        repository_id: UUID4,
+        repository_name: str,
+        repository_owner: str,
         git_hash: str,
         branch_name: str,
         status_name: str,
         return_all: bool = False,
     ):
         return self.client.get_deployments(
-            deployment_id=deployment_id,
+            repository_id=repository_id,
+            repository_name=repository_name,
+            repository_owner=repository_owner,
             git_hash=git_hash,
             branch_name=branch_name,
             status_name=status_name,
@@ -27,14 +31,9 @@ class GetDeployments(BaseDeploymentApiCommand):
 
 class GetRepositories(BaseDeploymentApiCommand):
     def execute(
-        self,
-        repository_id: UUID4,
-        repository_name: str,
-        repository_owner: str,
-        return_all: bool = False,
+        self, repository_name: str, repository_owner: str, return_all: bool = False,
     ):
         return self.client.get_repositories(
-            repository_id=repository_id,
             repository_name=repository_name,
             repository_owner=repository_owner,
             return_all=return_all,
@@ -43,10 +42,27 @@ class GetRepositories(BaseDeploymentApiCommand):
 
 class GetEndpoints(BaseDeploymentApiCommand):
     def execute(
-        self, endpoint_id: UUID4, endpoint_name: str, return_all: bool = False
+        self,
+        deployment_id: UUID4,
+        repository_name: str,
+        repository_owner: str,
+        git_hash: str,
+        branch_name: str,
+        status_name: str,
+        endpoint_name: str,
+        endpoint_kind: str,
+        return_all: bool = False,
     ) -> List[Endpoint]:
         return self.client.get_endpoints(
-            endpoint_id=endpoint_id, endpoint_name=endpoint_name, return_all=return_all
+            deployment_id=deployment_id,
+            repository_name=repository_name,
+            repository_owner=repository_owner,
+            git_hash=git_hash,
+            branch_name=branch_name,
+            status_name=status_name,
+            endpoint_name=endpoint_name,
+            endpoint_kind=endpoint_kind,
+            return_all=return_all,
         )
 
 
@@ -64,7 +80,7 @@ class ListDeploymentsCommand(BaseDeploymentApiCommand):
         # with halo.Halo(text=self.WAITING_FOR_RESPONSE_MESSAGE, spinner="dots"):
         #     instances = self._get_instances(**kwargs)
 
-        raise NotImplemented
+        raise NotImplementedError
 
 
 class GetDeploymentDetails(BaseDeploymentApiCommand):
@@ -73,7 +89,7 @@ class GetDeploymentDetails(BaseDeploymentApiCommand):
 
     def execute(self, id_):
         # TODO: get deployment details
-        raise NotImplemented
+        raise NotImplementedError
 
 
 class GetDeploymentMetricsCommand(BaseDeploymentApiCommand):
@@ -81,22 +97,22 @@ class GetDeploymentMetricsCommand(BaseDeploymentApiCommand):
         self, deployment_id, start, end, interval, built_in_metrics, *args, **kwargs
     ):
         # TODO: stream metrics
-        raise NotImplemented
+        raise NotImplementedError
 
 
 class StreamDeploymentMetricsCommand(BaseDeploymentApiCommand):
     def execute(self, **kwargs):
         # TODO: stream metrics
-        raise NotImplemented
+        raise NotImplementedError
 
 
 class DeploymentLogsCommand(BaseDeploymentApiCommand):
     def execute(self, **kwargs):
         # TODO: get logs
-        raise NotImplemented
+        raise NotImplementedError
 
     def _get_log_row_string(self, id, log):
-        raise NotImplemented
+        raise NotImplementedError
 
     def _make_table(self, logs, id):
-        raise NotImplemented
+        raise NotImplementedError
