@@ -23,6 +23,8 @@ class AuthConfigManager(BaseConfigManager):
     def set_api_key(cls, api_key: str) -> Dict:
         cfg = cls.get_tktl_config()
         if cfg:
+            if cfg["api-key"] == api_key:
+                return {"api-key": api_key}
             cfg["api-key"] = api_key
             return cls.set_tktl_config(cfg)
         else:
