@@ -57,10 +57,20 @@ class DockerManager:
     def _remove_patched_docker_file(self, file_path: str = TESTING_DOCKERFILE):
         os.remove(os.path.join(self._path, file_path))
 
+    def remove_image(self, image):
+        self._client.images.remove(image, force=True)
+
     def build_image(
         self, dockerfile: str, nocache: bool = False, buildargs: Dict = None
     ) -> str:
 
+        if nocache:
+            try:
+                image = self._client.images.get("taktile-cli-test:latest")
+                self._client.images.remove(image.id)
+            except docker.errors.ImageNotFound:
+                pass
+
         # TODO: After phasing out support for non multistage docker files, remove this.
         if DockerManager._is_multi_stage(dockerfile):
             LOG.log(
@@ -73,6 +83,7 @@ class DockerManager:
                 nocache=nocache,
                 target=MULTI_STAGE_BUILD_STEP_NAME,
                 buildargs=buildargs,
+                forcerm=True,
             )
         else:
             LOG.log("Patching dockerfile...")
@@ -84,6 +95,7 @@ class DockerManager:
                 dockerfile=TESTING_DOCKERFILE,
                 tag="taktile-cli-test",
                 nocache=nocache,
+                forcerm=True,
             )
             self._remove_patched_docker_file()
 
@@ -91,21 +103,24 @@ class DockerManager:
 
     def test_import(self, image_id: str):
         container = self._client.containers.run(
-            image_id, "python -c 'from src.endpoints import tktl'", detach=True
+            image_id,
+            "python -c 'from src.endpoints import tktl'",
+            detach=True,
+            remove=True,
         )
         self.stream_logs(container)
 
         status = container.wait()
-        return status, container.logs()
+        return status, container
 
     def test_unittest(self, image_id: str):
         container = self._client.containers.run(
-            image_id, "python -m pytest ./user_tests/", detach=True
+            image_id, "python -m pytest ./user_tests/", detach=True, remove=True
         )
         self.stream_logs(container)
 
         status = container.wait()
-        return status, container.logs()
+        return status, container
 
     def run_rest_container(
         self, image_id: str, detach: bool = True, auth_enabled: bool = True
@@ -116,6 +131,7 @@ class DockerManager:
             entrypoint="/start-rest.sh",
             environment={"AUTH_ENABLED": auth_enabled},
             ports={"80/tcp": 8080},
+            remove=True,
             stderr=True,
             stdout=True,
         )
@@ -129,6 +145,7 @@ class DockerManager:
             entrypoint="/start-flight.sh",
             environment={"AUTH_ENABLED": auth_enabled},
             ports={"5005/tcp": 5005},
+            remove=True,
             stderr=True,
             stdout=True,
         )
@@ -150,10 +167,11 @@ class DockerManager:
             entrypoint="profiler profile -l",
             network_mode="host",
             detach=True,
+            remove=True,
         )
         self.stream_logs(container)
         status = container.wait()
-        return status, container.logs()
+        return status, container
 
     def run_and_check_health(
         self,
