@@ -1,7 +1,4 @@
-from typing import Union
-
 from tktl.core import ExtendedEnum
-from tktl.core.schemas.repository import Endpoint, Repository, RepositoryDeployment
 
 
 class UserRepoConfigFileNameT(str, ExtendedEnum):
@@ -16,6 +13,8 @@ class UserProjectFileT(str, ExtendedEnum):
 
 class RequiredUserProjectPathsT(str, ExtendedEnum):
     SRC = "src"
+    ASSETS = "assets"
+    TESTS = "tests"
     TKTL_YML = "tktl.yml"
     TKTL_YAML = "tktl.yaml"
     DOCKERFILE = ".buildfile"
@@ -27,21 +26,41 @@ class RequiredUserProjectPathsT(str, ExtendedEnum):
 
     @classmethod
     def strictly_required_dirs(cls):
-        return {cls.SRC.value}
+        return {cls.SRC.value, cls.ASSETS.value, cls.TESTS.value}
+
+
+class DeploymentStateFailed(str, ExtendedEnum):
+    BUILDING_FAILED = "building_failed"
+    DEPLOYING_FAILED = "deploying_failed"
+    ROUTING_FAILED = "routing_failed"
+    ERRORED = "errored"
+
+
+class DeploymentStateSucceed(str, ExtendedEnum):
+    RUNNING = "running"
+
+
+class DeploymentStatePending(str, ExtendedEnum):
+    BUILDING = "building"
+    DEPLOYING = "deploying"
+    ROUTING = "routing"
 
 
 class DeploymentStatesT(str, ExtendedEnum):
-    PRE_ORION_UNKNOWN_ERROR = "errored"
-    TEST_FAILED = "test_failed"
-    IMAGE_BUILD_FAILED = "image_build_failed"
-    DEPLOYMENT_FAILED = "deployment_failed"
-    CANCELED = "canceled"
-    SUCCEEDED = "succeeded"
-    TEST_RUNNING = "test_running"
-    IMAGE_BUILDING = "image_building"
+
+    BUILDING = "building"
     DEPLOYING = "deploying"
-    MARKED_FOR_DELETION = "marked_for_deletion"
-    DELETION_FAILED = "deletion_failed"
+    ROUTING = "routing"
+    RUNNING = "running"
+    DELETED = "deleted"
+
+    BUILDING_FAILED = "building_failed"
+    DEPLOYING_FAILED = "deploying_failed"
+
+    ROUTING_FAILED = "routing_failed"
+
+    # Error after entering the running state
+    ERRORED = "errored"
 
 
 class ProjectAssetT(str, ExtendedEnum):
@@ -56,11 +75,26 @@ class ProjectAssetSourceT(str, ExtendedEnum):
 
 
 class InstanceTypeT(str, ExtendedEnum):
+    # Also change in taktile-services: services/deployment-api/app/deployment_api/core/t/konduit.py
     GP_SMALL = "gp.small"
     GP_MEDIUM = "gp.medium"
     GP_LARGE = "gp.large"
     GP_XLARGE = "gp.xlarge"
-    GP_2XLARGE = "gp.2xlarge"
+    GP_2XLARGE = "gp.xxlarge"
+
+
+class InstanceSizeT(ExtendedEnum):
+    # also change in taktile-cli: tktl/core/t.py
+    SMALL = "small"
+    MEDIUM = "medium"
+    LARGE = "large"
+    XLARGE = "xlarge"
+    XXLARGE = "xxlarge"
+
+
+class ComputeTypeT(ExtendedEnum):
+    # general purpose
+    GP = "gp"
 
 
 class ServiceT(str, ExtendedEnum):
@@ -68,6 +102,11 @@ class ServiceT(str, ExtendedEnum):
     GRPC = "grpc"
 
 
+class ServiceKindT(str, ExtendedEnum):
+    REST = "rest"
+    ARROW = "arrow"
+
+
 class EndpointKinds(str, ExtendedEnum):
     CUSTOM = "custom"
     TABULAR = "tabular"
@@ -85,6 +124,10 @@ class RestSchemaTypes(ExtendedEnum):
     DATAFRAME = "DataFrame"
     SINGLE_VALUE = "SingleValue"
     CUSTOM_MODEL = "CustomModel"
+    ANY = "Any"
 
 
-Resources = Union[Repository, RepositoryDeployment, Endpoint]
+class AccessKind(str, ExtendedEnum):
+    # see also corresponding AccessKind on t-api
+    OWNER = "owner"
+    VIEWER = "viewer"
