@@ -1,5 +1,5 @@
 import click
-import click_completion
+import click_completion  # type: ignore
 
 from tktl.cli.common import ClickGroup
 from tktl.cli.delete import delete as delete_commands
